==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesAk.php <==
<?php
/** Akan (Akan)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Kasahorow
 * @author Natsubee
 * @author Paa.kwesi
 */

$messages = array(
# User preference toggles
'tog-underline'             => 'Twa lenk nyina ase:',
'tog-highlightbroken'       => 'Fɔɔmat nlink a wɔnnyɛ edwuma <a href="" class="new">like this</a> (alternative: like this<a href="" class="internal">?</a>)',
'tog-justify'               => 'Gyastefae mparagraf',
'tog-hideminor'             => 'Suma nsesae a wɔakɔ so a wɔnnkyɛree koraa',
'tog-hidepatrolled'         => 'Suma nsesae a wɔapatrole wɔn ndansa yi ara',
'tog-newpageshidepatrolled' => 'Suma nkrataafa a wɔapatrole wɔn fi krataafa-foforo lest no so',
'tog-extendwatchlist'       => 'San list-nhwɛso no mu ama wo ehu nsesae nyinara a wɔakɔ so',
'tog-usenewrc'              => 'Fa ndansa nsesae a woetu mpon fa di dwuma (wo hia JavaScript)',
'tog-numberheadings'        => 'Ma ti-nsɛm no ara ankasa mma wɔn ho nɔmba',
'tog-showtoolbar'           => 'Kyerɛ tulbaa a wɔde yɛ nsesa (wo hia JavaScript)',
'tog-editondblclick'        => 'Sesa nkrataafa sɛ womia klik mpɛn mienu a (wo hia JavaScript)',

# Dates
'sunday'    => 'Kwasiada',
'monday'    => 'Ɛdwoada',
'tuesday'   => 'Ɛbenada',
'wednesday' => 'Wukuada',
'thursday'  => 'Yawoada',
'friday'    => 'Efiada',
'saturday'  => 'Memeneda',
'january'   => 'Ɔpɛpɔn',
'february'  => 'Ɔgyefuo',
'march'     => 'Ɔbenem',
'april'     => 'Oforisuo',
'may_long'  => 'Kɔtonimma',
'june'      => 'Ayɛwohomumu',
'july'      => 'Kutawonsa',
'august'    => 'Ɔsannaa',
'september' => 'Ɛbɔ',
'october'   => 'Ahinime',
'november'  => 'Obubuo',
'december'  => 'Ɔpenimma',

# Categories related messages
'listingcontinuesabbrev' => 'toa so',

'search'           => 'Hwehwɛ',
'searchbutton'     => 'Hwehwɛ',
'go'               => 'Kɔ',
'searcharticle'    => 'Kɔ',
'history'          => 'Krataafa abakɔsɛm',
'history_short'    => 'Beeme',
'talkpagelinktext' => 'Kasa',
'talk'             => 'Kasa',
'jumptosearch'     => 'hwehwɛ',

# Login and logout pages
'login'                   => 'Bra mu',
'nav-login-createaccount' => 'Bra mu / yɛ akawnt',
'userlogin'               => 'Bra mu',
'logout'                  => 'Pue',
'userlogout'              => 'Pue',
'notloggedin'             => 'Mmbaa mu',
'nologin'                 => "Wo nni akawnt anaa? '''$1'''.",

# Search results
'powersearch' => 'Hwehwɛ',

# Preferences page
'searchresultshead' => 'Hwehwɛ',

# Recent changes
'hist' => 'beeme',

# Watchlist
'watch' => 'Hwɛ',

);

==> mediawiki-1.18.5.tbz: www/mediawiki/languages/messages/MessagesAk.php <==
<?php
/** Akan (Akan)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Kasahorow
 * @author Natsubee
 * @author Paa.kwesi
 */

$messages = array(
# User preference toggles
'tog-underline'             => 'Twa lenk nyina ase:',
'tog-highlightbroken'       => 'Fɔɔmat nlink a wɔnnyɛ edwuma <a href="" class="new">like this</a> (alternative: like this<a href="" class="internal">?</a>)',
'tog-justify'               => 'Gyastefae mparagraf',
'tog-hideminor'             => 'Suma nsesae a wɔakɔ so a wɔnnkyɛree koraa',
'tog-hidepatrolled'         => 'Suma nsesae a wɔapatrole wɔn ndansa yi ara',
'tog-newpageshidepatrolled' => 'Suma nkrataafa a wɔapatrole wɔn fi krataafa-foforo lest no so',
'tog-extendwatchlist'       => 'San list-nhwɛso no mu ama wo ehu nsesae nyinara a wɔakɔ so',
'tog-usenewrc'              => 'Fa ndansa nsesae a woetu mpon fa di dwuma (wo hia JavaScript)',
'tog-numberheadings'        => 'Ma ti-nsɛm no ara ankasa mma wɔn ho nɔmba',
'tog-showtoolbar'           => 'Kyerɛ tulbaa a wɔde yɛ nsesa (wo hia JavaScript)',
'tog-editondblclick'        => 'Sesa nkrataafa sɛ womia klik mpɛn mienu a (wo hia JavaScript)',

# Dates
'sunday'    => 'Kwasiada',
'monday'    => 'Ɛdwoada',
'tuesday'   => 'Ɛbenada',
'wednesday' => 'Wukuada',
'thursday'  => 'Yawoada',
'friday'    => 'Efiada',
'saturday'  => 'Memeneda',
'january'   => 'Ɔpɛpɔn',
'february'  => 'Ɔgyefuo',
'march'     => 'Ɔbenem',
'april'     => 'Oforisuo',
'may_long'  => 'Kɔtonimma',
'june'      => 'Ayɛwohomumu',
'july'      => 'Kutawonsa',
'august'    => 'Ɔsannaa',
'september' => 'Ɛbɔ',
'october'   => 'Ahinime',
'november'  => 'Obubuo',
'december'  => 'Ɔpenimma',

# Categories related messages
'listingcontinuesabbrev' => 'toa so',

'search'           => 'Hwehwɛ',
'searchbutton'     => 'Hwehwɛ',
'go'               => 'Kɔ',
'searcharticle'    => 'Kɔ',
'history'          => 'Krataafa abakɔsɛm',
'history_short'    => 'Abakɔsɛm',
'talkpagelinktext' => 'Kasa',
'talk'             => 'Nkɔmbɔ',
'jumptosearch'     => 'hwehwɛ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite' => 'Fa {{SITENAME}} ho',
'mainpage'  => 'Krataafa Titiriw',

'editsection'     => 'sesa',
'editsectionhint' => 'Sesa sɛkhyɛn: $1',
'red-link-title'  => '$1 (krataafa nni hɔ)',

# Login and logout pages
'login'                   => 'Bra mu',
'nav-login-createaccount' => 'Bra mu / yɛ akawnt',
'userlogin'               => 'Bra mu / yɛ akawnt',
'logout'                  => 'Pue',
'userlogout'              => 'Pue',
'notloggedin'             => 'Mmbaa mu',
'nologin'                 => 'Wo nni akawnt anaa? $1.',

# Search results
'powersearch' => 'Hwehwɛ',

# Preferences page
'searchresultshead' => 'Hwehwɛ',

# Recent changes
'hist' => 'abakɔsɛm',

# Watchlist
'watch' => 'Hwɛ',

'sp-contributions-talk' => 'Kasa',

);
